Python: module rss

rss (version 0.0.1) | index rss.py

`This tool runs CLI scripts and displays output in a Web Interface.
This file implements a RSS feed.`

Classes
`` |  | builtins.object Feed enum.Enum(builtins.object) FIELDS
class FIELDS(enum.Enum)
`` | `FIELDS(value, names=None, *, module=None, qualname=None, type=None, start=1) An enumeration.`
| Method resolution order: FIELDS enum.Enum builtins.object Data and other attributes defined here: author = <FIELDS.author: 1> categories = <FIELDS.categories: 5> comments = <FIELDS.comments: 7> description = <FIELDS.description: 3> guid = <FIELDS.guid: 0> link = <FIELDS.link: 4> pubDate = <FIELDS.pubDate: 6> title = <FIELDS.title: 2> Data descriptors inherited from enum.Enum: name `The name of the Enum member.` value `The value of the Enum member.` Readonly properties inherited from enum.EnumMeta: __members__ `Returns a mapping of member name->value. This mapping lists all enum members, including aliases. Note that this is a read-only view of the internal mapping.`
class Feed(builtins.object)
`` | `Feed(environ: os._Environ, user: ~User, server: ~Server, category: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -&gt; Tuple[str, Dict[str, str], Iterable[bytes]] This class implements the RSS feed.`
| Class methods defined here: csv(environ: os._Environ, user: ~User, server: ~Server, category: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] from builtins.type `This function prints the RSS feed content as CSV.` generator(full_url: str, base_url: str, rss_path: str, category: str) -> Iterable[bytes] from builtins.type `This generator returns RSS feed content.` json(environ: os._Environ, user: ~User, server: ~Server, category: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], str] from builtins.type `This function prints the RSS feed content as JSON.` Static methods defined here: __new__(cls: type, environ: os._Environ, user: ~User, server: ~Server, category: str, arguments: Dict[str, Dict[str, str]], inputs: List[str], csrf_token: str = None) -> Tuple[str, Dict[str, str], Iterable[bytes]] `This function prints the RSS feed.` Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: __annotations__ = {'default': typing.List[str], 'optional': typing.List[str], 'required': typing.List[str], 'rss_path': <class 'str'>} default = ['author', 'guid', 'pubDate', 'lastBuildDate'] optional = ['comments'] required = ['title', 'description', 'link', 'categories'] rss_path = None

Functions
`` |  | get_rss_path(server: ~Server) -> str `This function returns the rss path.` localtime(...) `localtime([seconds]) -> (tm_year,tm_mon,tm_mday,tm_hour,tm_min, tm_sec,tm_wday,tm_yday,tm_isdst) Convert seconds since the Epoch to a time tuple expressing local time. When 'seconds' is not passed in, convert the current time instead.` strftime(...) `strftime(format[, tuple]) -> string Convert a time tuple to a string according to a format specification. See the library reference manual for formatting codes. When the time tuple is not present, current time as returned by localtime() is used. Commonly used format codes: %Y Year with century as a decimal number. %m Month as a decimal number [01,12]. %d Day of the month as a decimal number [01,31]. %H Hour (24-hour clock) as a decimal number [00,23]. %M Minute as a decimal number [00,59]. %S Second as a decimal number [00,61]. %z Time zone offset from UTC. %a Locale's abbreviated weekday name. %A Locale's full weekday name. %b Locale's abbreviated month name. %B Locale's full month name. %c Locale's appropriate date and time representation. %I Hour (12-hour clock) as a decimal number [01,12]. %p Locale's equivalent of either AM or PM. Other codes may be available on your platform. See documentation for the C library strftime function.` writer(...) `csv_writer = csv.writer(fileobj [, dialect='excel'] [optional keyword args]) for row in sequence: csv_writer.writerow(row) [or] csv_writer = csv.writer(fileobj [, dialect='excel'] [optional keyword args]) csv_writer.writerows(rows) The "fileobj" argument can be any object that supports the file API.`

Data
`` |  | Dict = typing.Dict Iterable = typing.Iterable List = typing.List QUOTE_ALL = 1 Server = ~Server Tuple = typing.Tuple User = ~User __author_email__ = 'mauricelambert434@gmail.com' __copyright__ = '\nWebScripts Copyright (C) 2021, 2022, 2023 Mau...ome to redistribute it\nunder certain conditions.\n' __description__ = '\nThis tool runs CLI scripts and displays output ...Web Interface.\n\nThis file implements a RSS feed.\n' __license__ = 'GPL-3.0 License' __maintainer__ = 'Maurice Lambert' __maintainer_email__ = 'mauricelambert434@gmail.com' __url__ = 'https://github.com/mauricelambert/WebScripts' copyright = '\nWebScripts Copyright (C) 2021, 2022, 2023 Mau...ome to redistribute it\nunder certain conditions.\n' license = 'GPL-3.0 License'

Author
`` |  | Maurice Lambert